==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QPlainTextDocumentLayout_shell.h <==
#ifndef QPLAINTEXTDOCUMENTLAYOUT_SHELL_H
#define QPLAINTEXTDOCUMENTLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtwidgets-config.h>
#if QT_CONFIG(textedit)
#include <QtWidgets/qplaintextedit.h>
#endif //QT_CONFIG(textedit)
#include <QtJambi/QtJambiAPI>
#include <QAbstractTextDocumentLayout>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qabstracttextdocumentlayout.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpainter.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextlayout.h>
#include <QtGui/qtextobject.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(textedit)

class QPlainTextDocumentLayout_shell : public QPlainTextDocumentLayout, public QtJambiShellInterface
{
public:
    QPlainTextDocumentLayout_shell(QTextDocument* document0);
    ~QPlainTextDocumentLayout_shell() override;

    QRectF blockBoundingRect(const QTextBlock& block0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void documentChanged(int from0, int arg__2, int charsAdded2) override;
    QSizeF documentSize() const override;
    void draw(QPainter* arg__1, const QAbstractTextDocumentLayout::PaintContext& arg__2) override;
    void drawInlineObject(QPainter* painter0, const QRectF& rect1, QTextInlineObject object2, int posInDocument3, const QTextFormat& format4) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QRectF frameBoundingRect(QTextFrame* arg__1) const override;
    int hitTest(const QPointF& arg__1, Qt::HitTestAccuracy arg__2) const override;
    int pageCount() const override;
    void positionInlineObject(QTextInlineObject item0, int posInDocument1, const QTextFormat& format2) override;
    void resizeInlineObject(QTextInlineObject item0, int posInDocument1, const QTextFormat& format2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlainTextDocumentLayout_access : public QPlainTextDocumentLayout
{
    jobject __qt_blockBoundingRect_cref_QTextBlock_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0) const;
    void __qt_documentChanged_int_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint from0, jint arg__2, jint charsAdded2);
    jobject __qt_documentSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_draw_QPainter_ptr_cref_QAbstractTextDocumentLayout_PaintContext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, QtJambiNativeID arg__2);
    jobject __qt_frameBoundingRect_QTextFrame_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    jint __qt_hitTest_cref_QPointF_Qt_HitTestAccuracy_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, jint arg__2) const;
    jint __qt_pageCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QT_CONFIG(textedit)
#endif // QPLAINTEXTDOCUMENTLAYOUT_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QPlainTextDocumentLayout_shell.h <==
#ifndef QPLAINTEXTDOCUMENTLAYOUT_SHELL_H
#define QPLAINTEXTDOCUMENTLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(textedit)
#include <QtWidgets/qplaintextedit.h>
#endif //QT_CONFIG(textedit)
#include <QtJambi/QtJambiAPI>
#include <QAbstractTextDocumentLayout>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qabstracttextdocumentlayout.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpainter.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextlayout.h>
#include <QtGui/qtextobject.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(textedit)

class QPlainTextDocumentLayout_shell : public QPlainTextDocumentLayout, public QtJambiShellInterface
{
public:
    QPlainTextDocumentLayout_shell(QTextDocument* document0);
    ~QPlainTextDocumentLayout_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QPlainTextDocumentLayout_mshell;
    friend class QPlainTextDocumentLayout_oshell;
};


class QPlainTextDocumentLayout_mshell : public QPlainTextDocumentLayout_shell
{
public:
    using QPlainTextDocumentLayout_shell::QPlainTextDocumentLayout_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QPlainTextDocumentLayout_oshell : public QPlainTextDocumentLayout_mshell
{
public:
    using QPlainTextDocumentLayout_mshell::QPlainTextDocumentLayout_mshell;
    QRectF blockBoundingRect(const QTextBlock& block0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void documentChanged(int from0, int arg__2, int charsAdded2) override;
    QSizeF documentSize() const override;
    void draw(QPainter* arg__1, const QAbstractTextDocumentLayout::PaintContext& arg__2) override;
    void drawInlineObject(QPainter* painter0, const QRectF& rect1, QTextInlineObject object2, int posInDocument3, const QTextFormat& format4) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QRectF frameBoundingRect(QTextFrame* arg__1) const override;
    int hitTest(const QPointF& arg__1, Qt::HitTestAccuracy arg__2) const override;
    int pageCount() const override;
    void positionInlineObject(QTextInlineObject item0, int posInDocument1, const QTextFormat& format2) override;
    void resizeInlineObject(QTextInlineObject item0, int posInDocument1, const QTextFormat& format2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlainTextDocumentLayout_access : public QPlainTextDocumentLayout
{
    jobject __qt_blockBoundingRect_cref_QTextBlock_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0) const;
    void __qt_documentChanged_int_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint from0, jint arg__2, jint charsAdded2);
    jobject __qt_documentSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_draw_QPainter_ptr_cref_QAbstractTextDocumentLayout_PaintContext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, QtJambiNativeID arg__2);
    jobject __qt_frameBoundingRect_QTextFrame_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    jint __qt_hitTest_cref_QPointF_Qt_HitTestAccuracy_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, jint arg__2) const;
    jint __qt_pageCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QT_CONFIG(textedit)
#endif // QPLAINTEXTDOCUMENTLAYOUT_SHELL_H
